#
# spec file for package mpv-mpris
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%bcond_with tests


Name:           mpv-mpris
Version:        1.1
Release:        1.4%{?dist}
Summary:        MPRIS plugin for mpv
License:        MIT
Group:          Productivity/Multimedia/Video/Players
URL:            https://github.com/hoyon/mpv-mpris
Source0:        https://github.com/hoyon/mpv-mpris/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
%if %{with tests}
BuildRequires:  mpv
BuildRequires:  sound-theme-freedesktop
BuildRequires:  /bin/xvfb-run
BuildRequires:  dbus
BuildRequires:  playerctl
BuildRequires:  jq
BuildRequires:  socat
BuildRequires:  awk
%endif
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.58
BuildRequires:  pkgconfig(mpv)
BuildRequires:  pkgconfig(libavformat)
Supplements:    mpv
Conflicts:      mpv-plugin-mpris

%description
This package contains a plugin for mpv which allows control of the
player using the MPRIS D-Bus interface, which enables control with
multimedia keys in desktop environments such as GNOME and KDE
as well as through tools like playerctl.

%prep
%setup -q
%autopatch -p1

%build
%make_build CFLAGS=-g

%install
install -Dm0755 mpris.so %{buildroot}%{_libdir}/mpv/mpris.so
mkdir -p %{buildroot}%{_sysconfdir}/mpv/scripts
ln -s %{_libdir}/mpv/mpris.so %{buildroot}%{_sysconfdir}/mpv/scripts/mpris.so

%if %{with tests}
#test suite does not work on OBS VM
%check
%make_build test
%endif

%files
%license LICENSE
%{_libdir}/mpv
%{_sysconfdir}/mpv/scripts/mpris.so

%changelog
* Sun Sep 17 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to 1.1
  * Fix idle -> playing state transition
    gh#hoyon/mpv-mpris#90
  * add support for embedded cover art
    gh#hoyon/mpv-mpris#94
* Mon Apr  3 2023 Mia Herkt <mia@0x0.st>
- Update to 1.0
  * rename album fields to match MusicBrainz internal names
    gh#hoyon/mpv-mpris#81
  * Fix string leaks in property change handler
    gh#hoyon/mpv-mpris#84
  * Makefile: Allow to append CFLAGS / LDFLAGS from environment.
    gh#hoyon/mpv-mpris#87
  * Do not use the default GMainContext
    gh#hoyon/mpv-mpris#88
* Thu Sep 29 2022 Mia Herkt <mia@0x0.st>
- Update to 0.9
  * expose musicbrainz metadata if available
    gh#hoyon/mpv-mpris#79
  * Fix test failure with glib 2.73.3
    gh#hoyon/mpv-mpris#80
* Fri Jun 17 2022 Mia Herkt <mia@0x0.st>
- Update to 0.8.1
  * Fix Unknown Artist for YouTube videos
    [#]gh/hoyon/mpv-mpris#76
  * Emit signal for fullscreen event
    [#]gh/hoyon/mpv-mpris#78
* Wed Jun 15 2022 Mia Herkt <mia@0x0.st>
- Update to 0.7.1
  * Add test suite
  * Emit Stopped Signal on exit.
    [#]gh/hoyon/mpv-mpris#61
    [#]gh/hoyon/mpv-mpris#22
  * Set xesam:artist to channel name for YouTube videos.
    [#]gh/hoyon/mpv-mpris#50
* Sun Nov 21 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 0.6:
  * Fix YouTube regex including 0 to the numeric range
  * Fix LoopStatus property change signal
  * Fix loop-file change handler in mpv 0.33.0
  * Fix LoopStatus when numeric argument given to loop-file or loop-playlist
  * Full changelog: https://github.com/hoyon/mpv-mpris/compare/0.5...0.6
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to mpv-mpris 0.5:
  * Fixed some glib warnings
  * Uninitialise glib objects on shutdown
  * Fix dbus names with multiple instances
  * Use YouTube thumbnails as mpris:artUrl when playing YouTube videos
* Sat Jan 18 2020 Martin Herkt <9+suse@cirno.systems>
- init, 0.4
